@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from collections import deque
@@ -7,6 +7,7 @@ import datetime
 from gettext import gettext as _
 import gi
 import logging
+import os
 import sys
 import threading
 
@@ -72,6 +73,7 @@ CREDITS = dict(
         'abidin toumi (Arabic)',
         'Rayen Ghanmi (Arabic)',
         'Mohamed Abdalah Noh (Arabic)',
+        'Ahmed Najmawi (Arabic)',
         'Rafael Fontenelle (Brazilian Portuguese)',
         'Infinitive Witch (Brazilian Portuguese)',
         'Unidealistic Raccoon (Brazilian Portuguese)',
@@ -79,11 +81,15 @@ CREDITS = dict(
         'Juliano de Souza Camargo (Brazilian Portuguese)',
         'Giovanne Menicheli (Brazilian Portuguese)',
         'Fúlvio Alves (Brazilian Portuguese)',
+        'Felipe (Brazilian Portuguese)',
         'twlvnn (Bulgarian)',
         'Roger VC (Catalan)',
+        'Lukáš Linhart (Czech)',
+        'Jakub Soukup (Czech)',
         'Dingzhong Chen (Simplified Chinese)',
         'Eric-Song-Nop (Simplified Chinese)',
         'Inaha (Simplified Chinese)',
+        'LS-Shandong (Simplified Chinese)',
         'randint (Traditional Chinese)',
         'Zhao Se (Traditional Chinese)',
         'happylittle7 (Traditional Chinese)',
@@ -91,7 +97,10 @@ CREDITS = dict(
         'Philip Goto (Dutch)',
         'Koen Benne (Dutch)',
         'Mikachu (Dutch)',
+        'Danial Behzadi (Persian)',
+        'Muhammad Hussein Ammari (Persian)',
         'Jiri Grönroos (Finnish)',
+        'Ricky Tigg (Finnish)',
         'Irénée THIRION (French)',
         'Valéry Febvre (French)',
         'Mathieu B. (French)',
@@ -104,19 +113,26 @@ CREDITS = dict(
         'Tim (German)',
         'Sear Gasor (German)',
         'Vortex Acherontic (German)',
+        'Dlurak (German)',
         'Scrambled777 (Hindi)',
+        'mondstern (Hungarian)',
         'Milo Ivir (Croatian)',
         'Alifiyan Rosyidi (Indonesian)',
         'Alim Satria (Indonesian)',
         'Juan Manuel (Indonesian)',
+        'srntskl-111 (Indonesian)',
         'Mek101 (Italian)',
         'dedocc (Italian)',
         'Davide Mora (Italian)',
+        'Andrea Scarano (Italian)',
+        'pasquale ruotolo (Italian)',
+        'Velyvis (Lithuanian)',
         'Lili Kurek (Polish)',
         'Aleksander Warzyniak (Polish)',
         'ssantos (Portuguese)',
         'Ademario Cunha (Portuguese)',
         'SpiralPack 527 (Portuguese)',
+        'Lucas Silva Goulart (Portuguese)',
         'shima (Russian)',
         'Valentin Chernetsov (Russian)',
         'FIONover (Russian)',
@@ -126,6 +142,8 @@ CREDITS = dict(
         'gallegonovato (Spanish)',
         'Jesper (Swedish)',
         'PaneradFisk (Swedish)',
+        'Willem Dinkelspiel (Swedish)',
+        'தமிழ்நேரம் (Tamil)',
         'Ege Çelikçi (Turkish)',
         'Sabri Ünal (Turkish)',
         'Volkan Yıldırım (Turkish)',
@@ -156,6 +174,7 @@ class Application(Adw.Application):
 
         self.window = None
 
+        self.add_main_option_entries([])
         self.set_resource_base_path('/info/febvre/Komikku')
         GLib.set_application_name('Komikku')
 
@@ -245,7 +264,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
         self.builder.add_from_resource('/info/febvre/Komikku/ui/menu/main.xml')
 
         self.css_provider = Gtk.CssProvider.new()
-        Gtk.StyleContext.add_provider_for_display(Gdk.Display.get_default(), self.css_provider, 400)
+        Gtk.StyleContext.add_provider_for_display(Gdk.Display.get_default(), self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
 
         self.activity_indicator = Adw.Spinner(
             halign=Gtk.Align.CENTER, valign=Gtk.Align.CENTER, width_request=48, height_request=48, visible=False
@@ -283,6 +302,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
         self.application.set_accels_for_action('app.enter-search-mode', ['<Primary>f'])
         self.application.set_accels_for_action('app.fullscreen', ['F11'])
         self.application.set_accels_for_action('app.select-all', ['<Primary>a'])
+        self.application.set_accels_for_action('app.library.update', ['<Primary>r'])
         self.application.set_accels_for_action('app.preferences', ['<Primary>comma'])
         self.application.set_accels_for_action('app.shortcuts', ['<Primary>question'])
         self.application.set_accels_for_action('app.quit', ['<Primary>q', '<Primary>w'])
@@ -474,7 +494,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
 
         set_color_scheme()
 
-    def install_servers_modules(self, reinit=False):
+    def install_servers_modules(self):
         def run():
             res, status = install_servers_modules_from_repo(self.application.version)
             GLib.idle_add(complete, res, status)
@@ -482,8 +502,7 @@ class ApplicationWindow(Adw.ApplicationWindow):
         def complete(res, status):
             if res is True:
                 if status == 'updated':
-                    self.add_notification(_('Servers modules have been updated'))
-                self.reinit_servers_modules()
+                    self.restart(_('Servers modules have been updated'))
 
             elif res is False:
                 if status == 'unchanged':
@@ -497,13 +516,9 @@ class ApplicationWindow(Adw.ApplicationWindow):
                         cancel_label=_('Close'),
                     )
                     self.application.logger.info('Failed to updates servers modules: incompatible app version')
-                if reinit:
-                    self.reinit_servers_modules()
 
             else:
                 self.application.logger.info('Failed to update servers modules')
-                if reinit:
-                    self.reinit_servers_modules()
 
         thread = threading.Thread(target=run)
         thread.daemon = True
@@ -529,26 +544,9 @@ available in your region/language."""))
         # Override release notes
         dialog.set_release_notes("""
             <ul>
-                <li>[Reader] Paused pages animations when obscured</li>
-                <li>[Servers] Anteiku Scans (FR): Update</li>
-                <li>[Servers] Asura Scans For Free (EN): Update</li>
-                <li>[Servers] ED Scanlation (FR): Update</li>
-                <li>[Servers] EZmanga (EN): Update</li>
-                <li>[Servers] Kewn Scans (EN): Update</li>
-                <li>[Servers] MonkeyUser (EN): Update</li>
-                <li>[Servers] Pepper&amp;Carrot: Update</li>
-                <li>[Servers] Starbound Scans (FR): Update</li>
-                <li>[Servers] Terco Scans (ES): Update</li>
-                <li>[Servers] Webtoon Hatti (TR): Update</li>
-                <li>[Servers] Rukav Inari (ES): Disabled</li>
-                <li>[Servers] MangaWeebs (EN): Disabled</li>
-                <li>[Servers] LSComic (EN): Disabled</li>
-                <li>[Servers] Hunlight Scans (EN): Disabled</li>
-                <li>[Servers] Mode Scanlator (pt_BR): Disabled</li>
-                <li>[Servers] Best Manga (RU): Disabled</li>
-                <li>[Servers] Atikrost (TR): Disabled</li>
-                <li>[Servers] Perf Scan (FR): Disabled</li>
-                <li>[L10n] Updated Bulgarian, German and Polish translations</li>
+                <li>Fixed app crash due to changes in AVIF image format support</li>
+                <li>[Servers] MangaFire (EN/ES/ES_LA/FR/JA/PT/pt_BR): Update</li>
+                <li>[L10n] Updated Portuguese and Russian translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
@@ -672,20 +670,11 @@ available in your region/language."""))
 
         return Gdk.EVENT_STOP
 
-    def reinit_servers_modules(self):
-        """Used when origin of servers modules change"""
+    def restart(self, message):
+        def confirm_callback():
+            os.execv(sys.argv[0], sys.argv)
 
-        # Reload servers modules
-        init_servers_modules(Settings.get_default().external_servers_modules, reload_modules=True)
-
-        # Force re-instantiation of server instance variables
-        self.library.reinstantiate_servers()
-        self.card.reinstantiate_server()
-
-        for page in self.navigationview.get_navigation_stack():
-            if page.props.tag.startswith('explorer'):
-                self.explorer.reinstantiate_servers()
-                break
+        self.confirm(_('Restart?'), message, _('Restart'), confirm_callback)
 
     def save_window_size(self):
         if self.is_fullscreen():
